import { ClassConstructor } from "class-transformer";
import { CreateComment, CreateCommentLike, CreateCommentReport, DeleteComment, EditComment, GetComments, ListCommentReports, RemoveComment, ResolveCommentReport, SaveComment } from "./interfaces/api/comment";
import { AddModToCommunity, BanFromCommunity, BlockCommunity, CreateCommunity, DeleteCommunity, EditCommunity, FollowCommunity, GetCommunity, ListCommunities, RemoveCommunity, TransferCommunity } from "./interfaces/api/community";
import { AddAdmin, BanPerson, BlockPerson, ChangePassword, CreatePrivateMessage, DeleteAccount, DeletePrivateMessage, EditPrivateMessage, GetBannedPersons, GetPersonDetails, GetPersonMentions, GetPrivateMessages, GetReplies, GetReportCount, GetUnreadCount, Login, MarkAllAsRead, MarkCommentReplyAsRead, MarkPersonMentionAsRead, MarkPrivateMessageAsRead, PasswordChange, PasswordReset, Register, SaveUserSettings, VerifyEmail } from "./interfaces/api/person";
import { CreatePost, CreatePostLike, CreatePostReport, DeletePost, EditPost, GetPost, GetPosts, GetSiteMetadata, ListPostReports, LockPost, MarkPostAsRead, RemovePost, ResolvePostReport, SavePost, StickyPost } from "./interfaces/api/post";
import { ApproveRegistrationApplication, CreateSite, EditSite, GetModlog, GetSite, GetUnreadRegistrationApplicationCount, LeaveAdmin, ListRegistrationApplications, PurgeComment, PurgeCommunity, PurgePerson, PurgePost, ResolveObject, Search } from "./interfaces/api/site";
import { CommunityJoin, PostJoin, UserJoin } from "./interfaces/api/websocket";
import { UserOperation } from "./interfaces/others";
/**
 * Helps build lemmy websocket message requests, that you can use in your Websocket sends.
 *
 * You'll receive back a [[WebSocketResponse]].
 *
 * The return types for these are given in [[LemmyHttp]]
 */
export declare class LemmyWebsocket {
    constructor();
    /**
     * Log into lemmy.
     */
    login(form: Login): string;
    /**
     * A websocket join for your user.
     *
     * Allows your user to receive private messages and notifications.
     */
    userJoin(form: UserJoin): string;
    /**
     * A websocket join for the current post room.
     *
     * Allows your user to receive new comments and updates for that post.
     */
    postJoin(form: PostJoin): string;
    /**
     * A websocket join for a given community.
     *
     * Allows your user to receive community updates.
     *
     * Note: community_id: 0, is your front page.
     */
    communityJoin(form: CommunityJoin): string;
    /**
     * Register a new user.
     */
    register(register: Register): string;
    /**
     * Fetch a Captcha.
     */
    getCaptcha(): string;
    /**
     * Create a new community.
     */
    createCommunity(form: CreateCommunity): string;
    /**
     * Edit a community.
     */
    editCommunity(form: EditCommunity): string;
    /**
     * Delete a community.
     */
    deleteCommunity(form: DeleteCommunity): string;
    /**
     * A moderator remove for a community.
     */
    removeCommunity(form: RemoveCommunity): string;
    /**
     * Follow / subscribe to a community.
     */
    followCommunity(form: FollowCommunity): string;
    /**
     * List communities, with various filters.
     */
    listCommunities(form: ListCommunities): string;
    /**
     * Create a post.
     */
    createPost(form: CreatePost): string;
    /**
     * Get / fetch a post.
     */
    getPost(form: GetPost): string;
    /**
     * Get / fetch a community.
     */
    getCommunity(form: GetCommunity): string;
    /**
     * Create a comment.
     */
    createComment(form: CreateComment): string;
    /**
     * Edit a comment.
     */
    editComment(form: EditComment): string;
    /**
     * Delete a comment.
     */
    deleteComment(form: DeleteComment): string;
    /**
     * A moderator remove for a comment.
     */
    removeComment(form: RemoveComment): string;
    /**
     * Mark a comment as read.
     */
    markCommentReplyAsRead(form: MarkCommentReplyAsRead): string;
    /**
     * Like / vote on a comment.
     */
    likeComment(form: CreateCommentLike): string;
    /**
     * Save a comment.
     */
    saveComment(form: SaveComment): string;
    /**
     * Report a comment.
     */
    createCommentReport(form: CreateCommentReport): string;
    /**
     * Resolve a comment report. Only a mod can do this.
     */
    resolveCommentReport(form: ResolveCommentReport): string;
    /**
     * List comment reports.
     */
    listCommentReports(form: ListCommentReports): string;
    /**
     * Get / fetch posts, with various filters.
     */
    getPosts(form: GetPosts): string;
    /**
     * Get / fetch comments.
     */
    getComments(form: GetComments): string;
    /**
     * Like / vote on a post.
     */
    likePost(form: CreatePostLike): string;
    /**
     * Edit a post.
     */
    editPost(form: EditPost): string;
    /**
     * Delete a post.
     */
    deletePost(form: DeletePost): string;
    /**
     * A moderator remove for a post.
     */
    removePost(form: RemovePost): string;
    /**
     * A moderator can lock a post ( IE disable new comments ).
     */
    lockPost(form: LockPost): string;
    /**
     * A moderator can sticky a post ( IE stick it to the top of a community ).
     */
    stickyPost(form: StickyPost): string;
    /**
     * Mark a post as read.
     */
    markPostAsRead(form: MarkPostAsRead): string;
    /**
     * Save a post.
     */
    savePost(form: SavePost): string;
    /**
     * Report a post.
     */
    createPostReport(form: CreatePostReport): string;
    /**
     * Resolve a post report. Only a mod can do this.
     */
    resolvePostReport(form: ResolvePostReport): string;
    /**
     * List post reports.
     */
    listPostReports(form: ListPostReports): string;
    /**
     * Fetch metadata for any given site.
     */
    getSiteMetadata(form: GetSiteMetadata): string;
    /**
     * Ban a user from a community.
     */
    banFromCommunity(form: BanFromCommunity): string;
    /**
     * Add a moderator to your community.
     */
    addModToCommunity(form: AddModToCommunity): string;
    /**
     * Transfer your community to an existing moderator.
     */
    transferCommunity(form: TransferCommunity): string;
    /**
     * Leave the Site admins.
     */
    leaveAdmin(form: LeaveAdmin): string;
    /**
     * Ban a person from your site.
     */
    banPerson(form: BanPerson): string;
    /**
     * Get a list of banned users
     */
    getBannedPersons(form: GetBannedPersons): string;
    /**
     * Add an admin to your site.
     */
    addAdmin(form: AddAdmin): string;
    /**
     * Get the unread registration applications count.
     */
    getUnreadRegistrationApplicationCount(form: GetUnreadRegistrationApplicationCount): string;
    /**
     * List the unread registration applications.
     */
    listRegistrationApplications(form: ListRegistrationApplications): string;
    /**
     * Approve a registration application
     */
    approveRegistrationApplication(form: ApproveRegistrationApplication): string;
    /**
     * Get the details for a person.
     */
    getPersonDetails(form: GetPersonDetails): string;
    /**
     * Get comment replies.
     */
    getReplies(form: GetReplies): string;
    /**
     * Get mentions for your user.
     */
    getPersonMentions(form: GetPersonMentions): string;
    /**
     * Mark a person mention as read.
     */
    markPersonMentionAsRead(form: MarkPersonMentionAsRead): string;
    /**
     * Get the modlog.
     */
    getModlog(form: GetModlog): string;
    /**
     * Create your site.
     */
    createSite(form: CreateSite): string;
    /**
     * Edit your site.
     */
    editSite(form: EditSite): string;
    /**
     * Gets the site, and your user data.
     */
    getSite(form: GetSite): string;
    /**
     * Search lemmy.
     */
    search(form: Search): string;
    /**
     * Fetch a non-local / federated object.
     */
    resolveObject(form: ResolveObject): string;
    /**
     * Mark all replies as read.
     */
    markAllAsRead(form: MarkAllAsRead): string;
    /**
     * Save your user settings.
     */
    saveUserSettings(form: SaveUserSettings): string;
    /**
     * Change your user password.
     */
    changePassword(form: ChangePassword): string;
    /**
     * Get counts for your reports
     */
    getReportCount(form: GetReportCount): string;
    /**
     * Get your unread counts
     */
    getUnreadCount(form: GetUnreadCount): string;
    /**
     * Verify your email
     */
    verifyEmail(form: VerifyEmail): string;
    /**
     * Delete your account.
     */
    deleteAccount(form: DeleteAccount): string;
    /**
     * Reset your password.
     */
    passwordReset(form: PasswordReset): string;
    /**
     * Change your password from an email / token based reset.
     */
    passwordChange(form: PasswordChange): string;
    /**
     * Create a private message.
     */
    createPrivateMessage(form: CreatePrivateMessage): string;
    /**
     * Edit a private message.
     */
    editPrivateMessage(form: EditPrivateMessage): string;
    /**
     * Delete a private message.
     */
    deletePrivateMessage(form: DeletePrivateMessage): string;
    /**
     * Mark a private message as read.
     */
    markPrivateMessageAsRead(form: MarkPrivateMessageAsRead): string;
    /**
     * Get / fetch private messages.
     */
    getPrivateMessages(form: GetPrivateMessages): string;
    /**
     * Block a person.
     */
    blockPerson(form: BlockPerson): string;
    /**
     * Block a community.
     */
    blockCommunity(form: BlockCommunity): string;
    /**
     * Purge / Delete a person from the database.
     */
    purgePerson(form: PurgePerson): string;
    /**
     * Purge / Delete a community from the database.
     */
    purgeCommunity(form: PurgeCommunity): string;
    /**
     * Purge / Delete a post from the database.
     */
    purgePost(form: PurgePost): string;
    /**
     * Purge / Delete a comment from the database.
     */
    purgeComment(form: PurgeComment): string;
}
export declare function wsUserOp(msg: any): UserOperation;
/**
 * Converts a websocket string response to a usable result
 */
export declare function wsJsonToRes<ResponseType>(msg: any, responseClass: ClassConstructor<ResponseType>): ResponseType;
